install/central
===============

.. raw:: html

        <html><head><meta http-equiv="refresh" content="0; URL='../user-guide/configuration/admin-multi-user-install.html'" /></head><body></body></html>
